@@ -38,7 +38,7 @@ class YoutubeSession(Session):
             r = self.get(self.BASE_URL, headers={'User-Agent': user_agent_header})
         return parse_json_session_data(r)
 
-    def parse_session_data(self, data):
+    def _parse_session_data(self, data):
         self.data = data
         self.key = data['INNERTUBE_API_KEY']
         self.client = data['INNERTUBE_CONTEXT']
@@ -50,7 +50,7 @@ class YoutubeSession(Session):
             self.USER_AGENT = self.get_user_agent(self.preferred_user_agent)
             data = self.get_session_data(self.USER_AGENT)
             try:
-                self.parse_session_data(data)
+                self._parse_session_data(data)
                 break
             except KeyError:
                 continue
